@@ -6,6 +6,7 @@ import warnings
 from copy import deepcopy
 from itertools import chain
 
+import requests
 import typing
 import yaml
 from jsonref import JsonRef
@@ -20,6 +21,11 @@ from six.moves.urllib.request import url2pathname
 from swagger_spec_validator import validator20
 from swagger_spec_validator.ref_validators import in_scope
 
+try:
+    from yaml import CSafeLoader as SafeLoader
+except ImportError:
+    from yaml import SafeLoader  # type: ignore
+
 from bravado_core import formatter
 from bravado_core import version as _version
 from bravado_core.exception import SwaggerSchemaError
@@ -120,7 +126,7 @@ class Spec(object):
     ):
         self.spec_dict = spec_dict
         self.origin_url = origin_url
-        self.http_client = http_client
+        self.http_client = http_client or BasicHTTPClient()
         self.api_url = None
         self.config = dict(CONFIG_DEFAULTS, **(config or {}))
 
@@ -185,6 +191,7 @@ class Spec(object):
             if attr_name in {
                 'format_checker',   # jsonschema.FormatChecker does not define an equality method
                 'resolver',         # jsonschema.validators.RefResolver does not define an equality method
+                'http_client',      # this attribute may be different for the same values
             }:
                 continue
 
@@ -547,6 +554,23 @@ def is_yaml(url, content_type=None):
     return False
 
 
+# this has the minimal interface required for build_http_handlers, but should be
+# more or less compatible with bravado.http_future.HttpFuture
+class BasicHTTPFuture(object):
+    def __init__(self, request_params):
+        self.request_params = request_params
+
+    def result(self):
+        return requests.request(**self.request_params)
+
+
+# this has the minimal interface required for build_http_handlers, but should be
+# more or less compatible with bravado.http_client.HttpClient
+class BasicHTTPClient(object):
+    def request(self, request_params):
+        return BasicHTTPFuture(request_params)
+
+
 def build_http_handlers(http_client):
     """Create a mapping of uri schemes to callables that take a uri. The
     callable is used by jsonschema's RefResolver to download remote $refs.
@@ -564,14 +588,14 @@ def build_http_handlers(http_client):
         response = http_client.request(request_params).result()
         content_type = response.headers.get('content-type', '').lower()
         if is_yaml(uri, content_type):
-            return yaml.safe_load(response.content)
+            return yaml.load(response.content, Loader=SafeLoader)
         else:
             return response.json()
 
     def read_file(uri):
         with open(url2pathname(urlparse(uri).path), mode='rb') as fp:
             if is_yaml(uri):
-                return yaml.safe_load(fp)
+                return yaml.load(fp, Loader=SafeLoader)
             else:
                 return json.loads(fp.read().decode("utf-8"))
 
